import numpy as np
from scipy import stats
import asyncio
import uvloop

class BasicCalc:
    def __init__(self):
        self.self = self
        
    async def describeData(self, data: list):
        """Calculates the mean, median, standard deviation, and variance of the data
        
        Args:
            data (list): list of data
            
        Returns:
            _type_: class
        """
        npyArray = np.array(data)
        return stats.describe(npyArray)
    
    asyncio.set_event_loop_policy(uvloop.EventLoopPolicy())
    
    async def calcMode(self, data: list):
        """Returns the mode of the data

        Args:
            data (list): _list of data
            
        Returns:
            _type_: array
        """
        array = np.array(data)
        return stats.mode(array, axis=None)
    
    asyncio.set_event_loop_policy(uvloop.EventLoopPolicy())
    
    async def calcMean(self, data: list):
        """Returns the mean of the data

        Args:
            data (list): _list of data
            
        Returns:
            _type_: float
        """
        array = np.array(data)
        return stats.tmean(array)
    
    asyncio.set_event_loop_policy(uvloop.EventLoopPolicy())
    
    async def calcStd(self, data: list):
        """Calculates the standard deviation of the data

        Args:
            data (list): list of data

        Returns:
            _type_: float
        """
        npArr = np.array(data)
        return stats.tstd(npArr)
    
    asyncio.set_event_loop_policy(uvloop.EventLoopPolicy())
    
    async def calcVariance(self, data: list):
        """Calculates the variance of the data

        Args:
            data (list): list of data

        Returns:
            _type_: float
        """
        npArr = np.array(data)
        return stats.tvar(npArr)
    
    asyncio.set_event_loop_policy(uvloop.EventLoopPolicy())
    
    async def calcSem(self, dataSem: list):
        """Calculates the standard error of the mean
        
        Args: 
            dataSem (list): list of data
            
        Returns:
            __type__: float
        """
        a = np.array(dataSem)
        return stats.tsem(a)
    
    asyncio.set_event_loop_policy(uvloop.EventLoopPolicy())
    
    async def calcVar(self, data: list):
        """_summary_

        Args:
            data (list): list of data
            
        Returns:
            _type_: float
        """
        ar = np.array(data)
        return stats.tvar(ar)
    
    asyncio.set_event_loop_policy(uvloop.EventLoopPolicy())
    
    async def calcMin(self, data: list): 
        """_summary_

        Args:
            data (list): list of data
            
        Returns:
            _type_: float
        """
        arr = np.array(data)
        return stats.tmin(arr)
    
    asyncio.set_event_loop_policy(uvloop.EventLoopPolicy())
    
    async def calcMax(self, data: list): 
        """_summary_

        Args:
            data (list): list of data
            
        Returns:
            _type_: float
        """
        arr = np.array(data)
        return stats.tmax(arr)
    
    asyncio.set_event_loop_policy(uvloop.EventLoopPolicy())
    
    async def calcIqr(self, data: list):
        """_summary_

        Args:
            data (list): list of data
            
        Returns:
            _type_: float
        """
        aaarr = np.array(data)
        return stats.iqr(aaarr)
    
    asyncio.set_event_loop_policy(uvloop.EventLoopPolicy())




import numpy as np
from sklearn.linear_model import LinearRegression
import asyncio
import uvloop

class LinRegression:
    def __init__(self):
        self.self = self

    async def calcLinRegressionX(self, x_data: list, y_data: list):
        """Calculates the linear regression of the data for the x-axis

        Args:
            x_data (list): list of data for x-axis
            y_data (list): list of data for y-axis

        Returns:
            _type_: dict
        """
        x = np.array(x_data).reshape((-1, 1))
        y = np.array(y_data)
        model = LinearRegression().fit(x, y)
        r_sq = model.score(x, y)
        yIntercept = model.intercept_
        slope = model.coef_
        return {"r_sq": r_sq, "yIntercept": yIntercept, "slope": slope}

    asyncio.set_event_loop_policy(uvloop.EventLoopPolicy())

    async def calcLinRegressionY(self, x_new_data: list, y_new_data: list):
        """Calculates the linear regression of the data for the y-axis

        Args:
            x_new_data (list): list of data for x-axis
            y_new_data (list): list of data for y-axis

        Returns:
            _type_: dict
        """
        x_new = np.array(x_new_data)
        y_new = np.array(y_new_data).reshape((-1, 1))
        model = LinearRegression().fit(x_new, y_new)
        r_sq = model.score(x_new, y_new)
        yIntercept = model.intercept_
        slope = model.coef_
        return {"r_sq": r_sq, "yIntercept": yIntercept, "slope": slope}

    asyncio.set_event_loop_policy(uvloop.EventLoopPolicy())



import asyncio
import numpy as np
import uvloop
import matplotlib.pyplot as plt
import matplotlib.patches as patches
import matplotlib.path as path


class IchikaUtils:
    def __init__(self):
        self.self = self
        
    async def calcMean(self, array: list):
        """Calculates the mean from a list of data

        Args:
            array (list): _description_

        Returns:
            _type_: _description_
        """
        a = np.array(array)
        return np.mean(a)
    
    asyncio.set_event_loop_policy(uvloop.EventLoopPolicy())
    
    async def calcStats(self, array: list):
        """Returns the mean, median, standard deviation, and variance from a list of data

        Args:
            array (list): list of data

        Returns:
            _type_: dict
        """
        npyArray = np.array(array)
        return {"mean": np.mean(npyArray), "median": np.median(npyArray), "std": np.std(npyArray), "variances": np.var(npyArray)
                , "spread": np.ptp(npyArray)}
    
    asyncio.set_event_loop_policy(uvloop.EventLoopPolicy())
    
    async def calcShape(self, xList: list):
        """Calculates the shape of the data

        Args:
            xList (list): list of data

        Returns:
            _type_: numpy shape
        """
        xListArray = np.array(xList)
        rowShape = xListArray[:, np.newaxis]
        return rowShape.shape
        
    async def graphHistoRandn(self, amount: int):
        """Graphs a Histogram randomly

        Args:
            amount (int): The amount of data to be randomly generated and plotted
        """
        fig, ax = plt.subplots()
        np.random.seed(19680801)
        n, bins = np.histogram(amount, 50)
        left = bins[:-1]
        right = bins[1:]
        bottom = np.zeros(len(left))
        top = bottom + n
        XY = np.array([[left, left, right, right], [bottom, top, top, bottom]]).T
        barpath = path.Path.make_compound_path_from_polys(XY)
        patch = patches.PathPatch(barpath)
        ax.add_patch(patch)
        ax.set_xlim(left[0], right[-1])
        ax.set_ylim(bottom.min(), top.max())
        plt.show()
        
    asyncio.set_event_loop_policy(uvloop.EventLoopPolicy())

    async def graphSetHistogram(self, data: list):
        """Graphs a histogram of the data

        Args:
            data (list): list of data
        """
        fig, ax = plt.subplots()
        (hist, bin_edges) = np.histogram(data)
        left = bin_edges[:-1]
        right = bin_edges[1:]
        bottom = np.zeros(len(left))
        top = bottom + hist
        XY = np.array([[left, left, right, right], [bottom, top, top, bottom]]).T
        barpath = path.Path.make_compound_path_from_polys(XY)
        patch = patches.PathPatch(barpath)
        ax.add_patch(patch)
        ax.set_xlim(left[0], right[-1])
        ax.set_ylim(bottom.min(), top.max())
        plt.show()

    asyncio.set_event_loop_policy(uvloop.EventLoopPolicy())        
        
        
    
    
    
    



# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['ichika_utils']

package_data = \
{'': ['*']}

install_requires = \
['matplotlib>=3.5.2,<4.0.0',
 'pandas>=1.4.2,<2.0.0',
 'scikit-learn>=1.1.1,<2.0.0',
 'scipy>=1.8.0,<2.0.0',
 'uvloop>=0.16.0,<0.17.0']

setup_kwargs = {
    'name': 'ichika-utils',
    'version': '0.1.6',
    'description': 'Asynchronous Statistics Utils for Ichika',
    'long_description': '<div align=center>\n\n# Ichika Utils\n\n![PyPI - Python Version](https://img.shields.io/pypi/pyversions/ichika-utils?label=Python&logo=python&logoColor=white) ![PyPI](https://img.shields.io/pypi/v/ichika-utils?label=PyPi&logo=pypi&logoColor=white) ![PyPI - Downloads](https://img.shields.io/pypi/dd/ichika-utils?label=Downloads&logo=pypi&logoColor=white) [![CodeQL](https://github.com/No767/Ichika-Utils/actions/workflows/codeql.yml/badge.svg)](https://github.com/No767/Ichika-Utils/actions/workflows/codeql.yml) [![Snyk](https://github.com/No767/Ichika-Utils/actions/workflows/snyk.yml/badge.svg)](https://github.com/No767/Ichika-Utils/actions/workflows/snyk.yml) [![Bandit](https://github.com/No767/Ichika-Utils/actions/workflows/bandit.yml/badge.svg)](https://github.com/No767/Ichika-Utils/actions/workflows/bandit.yml) ![GitHub](https://img.shields.io/github/license/No767/Ichika-Utils?label=License&logo=github)\n\nAsynchronous Statistics Utils for Ichika\n\n<div align=left>\n\n# Info\n\nThis is a set of utils for Ichika, and this is not even production ready. This is highly experimental.\n',
    'author': 'No767',
    'author_email': '73260931+No767@users.noreply.github.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/No767/Ichika-Utils',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<3.11',
}


setup(**setup_kwargs)
